"""
Toxopy (https://github.com/bchaselab/Toxopy)
© M. Alyetama, University of Nebraska at Omaha
Licensed under the terms of the MIT license
"""

import warnings


def fwarnings():
    warnings.filterwarnings("ignore")


fwarnings()
